@@ -1,22 +1,15 @@
-##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.092/lib/Perl/Critic/Policy/InputOutput/ProhibitBacktickOperators.pm $
-#     $Date: 2008-09-02 09:43:48 -0700 (Tue, 02 Sep 2008) $
-#   $Author: thaljef $
-# $Revision: 2721 $
-##############################################################################
-
 package Perl::Critic::Policy::InputOutput::ProhibitBacktickOperators;
 
-use 5.006001;
+use 5.010001;
 use strict;
 use warnings;
 use Readonly;
 
 use Perl::Critic::Utils qw{ :severities is_in_void_context };
 
-use base 'Perl::Critic::Policy';
+use parent 'Perl::Critic::Policy';
 
-our $VERSION = '1.092';
+our $VERSION = '1.156';
 
 #-----------------------------------------------------------------------------
 
@@ -84,15 +77,15 @@ find that they make a lot of noise by filling up STDERR with messages
 when they fail.  I think its better to use IPC::Open3 to trap all the
 output and let the application decide what to do with it.
 
-  use IPC::Open3 'open3';
-  $SIG{CHLD} = 'IGNORE';
+    use IPC::Open3 'open3';
+    $SIG{CHLD} = 'IGNORE';
 
-  @output = `some_command`;                      #not ok
+    @output = `some_command`;                      #not ok
 
-  my ($writer, $reader, $err);
-  open3($writer, $reader, $err, 'some_command'); #ok;
-  @output = <$reader>;  #Output here
-  @errors = <$err>;     #Errors here, instead of the console
+    my ($writer, $reader, $err);
+    open3($writer, $reader, $err, 'some_command'); #ok;
+    @output = <$reader>;  #Output here
+    @errors = <$err>;     #Errors here, instead of the console
 
 
 =head1 CONFIGURATION
@@ -101,17 +94,17 @@ Alternatively, if you do want to use backticks, you can restrict
 checks to void contexts by adding the following to your
 F<.perlcriticrc> file:
 
-  [InputOutput::ProhibitBacktickOperators]
-  only_in_void_context = 1
+    [InputOutput::ProhibitBacktickOperators]
+    only_in_void_context = 1
 
 The purpose of backticks is to capture the output of an external
 command.  Use of them in a void context is likely a bug.  If the
 output isn't actually required, C<system()> should be used.  Otherwise
 assign the result to a variable.
 
-  `some_command`;                      #not ok
-  $output = `some_command`;            #ok
-  @output = `some_command`;            #ok
+    `some_command`;                      #not ok
+    $output = `some_command`;            #ok
+    @output = `some_command`;            #ok
 
 
 =head1 NOTES
@@ -122,15 +115,20 @@ C<qx{}>.
 See L<perlipc|perlipc> for more discussion on using C<wait()> instead
 of C<$SIG{CHLD} = 'IGNORE'>.
 
+You might consider using the C<capture()> function from the
+L<IPC::System::Simple|IPC::System::Simple> module for a safer way of
+doing what backticks do, especially on Windows.  The module also has a
+safe wrapper around C<system()>.
+
 
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer <thaljef@cpan.org>
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
 
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2008 Jeffrey Ryan Thalhammer.  All rights reserved.
+Copyright (c) 2005-2011 Imaginative Software Systems.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
