@@ -1,22 +1,15 @@
-##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.092/lib/Perl/Critic/Policy/RegularExpressions/RequireExtendedFormatting.pm $
-#     $Date: 2008-09-02 09:43:48 -0700 (Tue, 02 Sep 2008) $
-#   $Author: thaljef $
-# $Revision: 2721 $
-##############################################################################
-
 package Perl::Critic::Policy::RegularExpressions::RequireExtendedFormatting;
 
-use 5.006001;
+use 5.010001;
 use strict;
 use warnings;
 use Readonly;
 
 use Perl::Critic::Utils qw{ :severities };
-use Perl::Critic::Utils::PPIRegexp qw{ &get_modifiers &get_match_string };
-use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.092';
+use parent 'Perl::Critic::Policy';
+
+our $VERSION = '1.156';
 
 #-----------------------------------------------------------------------------
 
@@ -58,16 +51,16 @@ sub applies_to           {
 #-----------------------------------------------------------------------------
 
 sub violates {
-    my ( $self, $elem, undef ) = @_;
+    my ( $self, $elem, $doc ) = @_;
 
-    my $match = get_match_string($elem);
+    my $match = $elem->get_match_string();
     return if length $match <= $self->{_minimum_regex_length_to_complain_about};
     return if not $self->{_strict} and $match =~ m< \A [\s\w]* \z >xms;
 
-    my %mods = get_modifiers($elem);
-    if ( not $mods{x} ) {
-        return $self->violation( $DESC, $EXPL, $elem );
-    }
+    my $re = $doc->ppix_regexp_from_element( $elem )
+        or return;
+    $re->modifier_asserted( 'x' )
+        or return $self->violation( $DESC, $EXPL, $elem );
 
     return; # ok!;
 }
@@ -107,7 +100,7 @@ comments into the pattern, thus making them much more readable.
         [^\\']      # any non-special chars (i.e. not backslash or single quote)
         (?:         # then all of...
             \\ .    #    any explicitly backslashed char
-            [^\\']* #    followed by an non-special chars
+            [^\\']* #    followed by a non-special char
         )*          # ...repeated zero or more times
         '           # a closing single quote
     }x;
@@ -146,7 +139,7 @@ This option defaults to false.
 =head1 NOTES
 
 For common regular expressions like e-mail addresses, phone numbers,
-dates, etc., have a look at the L<Regex::Common|Regex::Common> module.
+dates, etc., have a look at the L<Regexp::Common|Regexp::Common> module.
 Also, be cautions about slapping modifier flags onto existing regular
 expressions, as they can drastically alter their meaning.  See
 L<http://www.perlmonks.org/?node_id=484238> for an interesting
@@ -154,14 +147,20 @@ discussion on the effects of blindly modifying regular expression
 flags.
 
 
+=head1 TO DO
+
+Add an exemption for regular expressions that contain C<\Q> at the
+front and don't use C<\E> until the very end, if at all.
+
+
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer  <thaljef@cpan.org>
+Jeffrey Ryan Thalhammer  <jeff@imaginative-software.com>
 
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2008 Jeffrey Ryan Thalhammer. All rights reserved.
+Copyright (c) 2005-2011 Imaginative Software Systems. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
