@@ -1,24 +1,17 @@
-##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/distributions/Perl-Critic/lib/Perl/Critic/PolicyConfig.pm $
-#     $Date: 2010-06-22 16:14:07 -0400 (Tue, 22 Jun 2010) $
-#   $Author: clonezone $
-# $Revision: 3843 $
-##############################################################################
-
 package Perl::Critic::PolicyConfig;
 
-use 5.006001;
+use 5.010001;
 use strict;
 use warnings;
 
 use Readonly;
 
-our $VERSION = '1.108';
+our $VERSION = '1.156';
 
 use Perl::Critic::Exception::AggregateConfiguration;
 use Perl::Critic::Exception::Configuration::Option::Policy::ParameterValue;
 use Perl::Critic::Exception::Configuration::Option::Policy::ExtraParameter;
-use Perl::Critic::Utils qw< :booleans :characters severity_to_number >;
+use Perl::Critic::Utils qw( :booleans :characters );
 use Perl::Critic::Utils::Constants qw< :profile_strictness >;
 
 #-----------------------------------------------------------------------------
@@ -161,9 +154,8 @@ sub get_parameter_names {
 sub handle_extra_parameters {
     my ($self, $policy, $errors) = @_;
 
-    my $profile_strictness = $self->{$NON_PUBLIC_DATA}{_profile_strictness};
-    defined $profile_strictness
-        or $profile_strictness = $PROFILE_STRICTNESS_DEFAULT;
+    my $profile_strictness = $self->{$NON_PUBLIC_DATA}{_profile_strictness}
+        // $PROFILE_STRICTNESS_DEFAULT;
 
     return if $profile_strictness eq $PROFILE_STRICTNESS_QUIET;
 
@@ -324,7 +316,7 @@ Elliot Shank <perl@galumph.com>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008-2010 Elliot Shank.
+Copyright (c) 2008-2023 Elliot Shank.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
